@@ -8,3 +8,5 @@ double exp2(double);
 double exp10(double);
 double cotan(double);
 double powr(double, double);
+void dsqrtv(double *, double *, int);
+void dsqrtiv(double *, double *, int);
